@@ -1,4 +1,6 @@
 package App::Dest;
+# ABSTRACT: Deployment State Manager
+
 use strict;
 use warnings;
 
@@ -10,7 +12,7 @@ use File::Path qw( mkpath rmtree );
 use IPC::Run 'run';
 use Text::Diff ();
 
-our $VERSION = '1.08';
+our $VERSION = '1.09'; # VERSION
 
 sub init {
     die "Project already initialized\n" if ( -d '.dest' );
@@ -114,7 +116,7 @@ sub status {
                 print "  + $b\n";
             }
             else {
-                ( my $action = $b ) =~ s\/(?:deploy|verify|revert)$\\;
+                ( my $action = $b ) =~ s,/(?:deploy|verify|revert)$,,;
                 print "  $action\n" unless ( $seen_actions{$action}++ );
                 print "    M $b\n";
             }
@@ -347,11 +349,22 @@ sub _action {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-dest - Deployment State Manager
+App::Dest - Deployment State Manager
+
+=head1 VERSION
+
+version 1.09
+
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/App-Dest.svg)](https://travis-ci.org/gryphonshafer/App-Dest)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/App-Dest/badge.png)](https://coveralls.io/r/gryphonshafer/App-Dest)
 
 =head1 SYNOPSIS
 
@@ -401,6 +414,8 @@ Using dest for production deployment, provisioning, or configuration management
 is not advised. Use something like Angular et al instead. Angular (or whatever
 CM tool you prefer) can use dest to perform some actions.
 
+=for test_synopsis BEGIN { die "SKIP: skip synopsis check because it's non-Perl\n"; }
+
 =head1 COMMANDS
 
 Typing just C<dest> should bring up the usage instructions, which include a
@@ -635,15 +650,45 @@ on whatever wrapper is in the current working directory.
 
 L<App::Sqitch>.
 
+You can also look for additional information at:
+
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/App-Dest>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/App-Dest>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/App::Dest>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/App-Dest>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/App-Dest>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/App-Dest>
+
+=back
+
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-  code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
